==> gadmin-openvpn-server_0.0.7.orig.tar.gz: gadmin-openvpn-server-0.0.7/src/export_button_clicked.c <==
/* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
 * Copyright (C) 2008 Magnus Loef <magnus-swe@telia.com> 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
*/


#include "../config.h"
#include <gtk/gtk.h>
#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include "widgets.h"
#include "gettext.h"
#include "show_info.h"
#include "commands.h"
#include "export_window.h"
#include "export_button_clicked.h"



void export_button_clicked(struct w *widgets)
{
    gchar *info, *cmd, *path;

    /* See if we have required things such as certs and client conf */
    path = g_strdup_printf("%s/server/certs/cert.pem", OPENVPN_SYSCONF_DIR);
    if( ! file_exists(path) )
    {
	info = g_strdup_printf(_("Generate new certificates in the server settings tab first.\n"));
	show_info(info);
	g_free(info);
	g_free(path);
	return;
    }
    g_free(path);

    path = g_strdup_printf("%s/server/client/gadmin-openvpn-client.conf", OPENVPN_SYSCONF_DIR);
    if( ! file_exists(path) )
    {
	info = g_strdup_printf(_("No client configuration has been created. You need to press apply first.\n"));
	show_info(info);
	g_free(info);
	g_free(path);
	return;
    }
    g_free(path);

    /* Tar up the client configuration directory and put it in the server directory. */
    cmd = g_strdup_printf("cd %s/server && tar -zcf gadmin-openvpn-client-data.tar.gz client/", OPENVPN_SYSCONF_DIR);
    if( ! run_command(cmd) )
    {
	info = g_strdup_printf(_("Error: Could not pack client configuration and certificates.\n"));
        show_info(info);
        g_free(info);
        g_free(cmd);
        return;
    }
    g_free(cmd);

    path = g_strdup_printf("%s/server/gadmin-openvpn-client-data.tar.gz", OPENVPN_SYSCONF_DIR);
    if( ! file_exists(path) )
    {
	info = g_strdup_printf(_("Error: No client configuration package has been created. Is the tar package installed ?.\n"));
	show_info(info);
	g_free(info);
	g_free(path);
	return;
    }
    g_free(path);


    /* Show the export window */
    show_export_window(widgets);
}

==> gadmin-openvpn-server_0.1.2.orig.tar.gz: gadmin-openvpn-server-0.1.2/src/export_button_clicked.c <==
/* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
 * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
*/


#include "../config.h"
#include <gtk/gtk.h>
#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include "widgets.h"
#include "gettext.h"
#include "show_info.h"
#include "commands.h"
#include "export_window.h"
#include "export_button_clicked.h"



void export_button_clicked(struct w *widgets)
{
    gchar *info, *cmd, *path;

    /* See if we have required things such as certs and client conf */
    path = g_strdup_printf("%s/server/certs/cert.pem", OPENVPN_SYSCONF_DIR);
    if( ! file_exists(path) )
    {
	info = g_strdup_printf(_("Generate new certificates in the server settings tab first.\n"));
	show_info(info);
	g_free(info);
	g_free(path);
	return;
    }
    g_free(path);

    path = g_strdup_printf("%s/server/client/gadmin-openvpn-client.conf", OPENVPN_SYSCONF_DIR);
    if( ! file_exists(path) )
    {
	info = g_strdup_printf(_("No client configuration has been created. You need to press apply first.\n"));
	show_info(info);
	g_free(info);
	g_free(path);
	return;
    }
    g_free(path);


    /* Copy server certs and keys to the client directory. */
    cmd = g_strdup_printf("cp %s/server/certs/{cacert.pem,cert.pem,dh.pem,key.pem,ta.key} %s/server/client/certs/",
									OPENVPN_SYSCONF_DIR, OPENVPN_SYSCONF_DIR);
    if( ! run_command(cmd) )
    {
	info = g_strdup_printf(_("Error: Could not copy certs and keys to the client directory.\n"));
        show_info(info);
        g_free(info);
        g_free(cmd);
        return;
    }
    g_free(cmd);


    /* Tar up the client configuration directory and put it in the server directory. */
    cmd = g_strdup_printf("cd %s/server && tar -zcf gadmin-openvpn-client-data.tar.gz client/", OPENVPN_SYSCONF_DIR);
    if( ! run_command(cmd) )
    {
	info = g_strdup_printf(_("Error: Could not pack client configuration and certificates.\n"));
        show_info(info);
        g_free(info);
        g_free(cmd);
        return;
    }
    g_free(cmd);

    path = g_strdup_printf("%s/server/gadmin-openvpn-client-data.tar.gz", OPENVPN_SYSCONF_DIR);
    if( ! file_exists(path) )
    {
	info = g_strdup_printf(_("Error: No client configuration package has been created. Is the tar package installed ?.\n"));
	show_info(info);
	g_free(info);
	g_free(path);
	return;
    }
    g_free(path);


    /* Show the export window */
    show_export_window(widgets);
}
